# pybasilica

**IMPORTANT:** This package is no longer maintained. Please switch to [pybascule](https://github.com/caravagnalab/pybascule) for future updates.

Detecting mutational signatures via bayesian inference and reference catalog

In this implementation, the model performs independent NMF and clustering on the mutation counts.
